==> 0.0.6.tar.gz: android/src/main/java/com/theflyy/flyy_flutter_plugin/FlyyFlutterPlugin.java <==
package com.theflyy.flyy_flutter_plugin;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.widget.Toast;

import androidx.annotation.NonNull;

import org.json.JSONObject;

import java.util.Map;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import theflyy.com.flyy.Flyy;
import theflyy.com.flyy.helpers.OnFlyyTaskComplete;
import theflyy.com.flyy.views.FlyyOffersActivity;

/** FlyyFlutterPlugin */
public class FlyyFlutterPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {

  private Context context;
  private Activity activity;
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;

  private final String FLYY_INIT = "flyy_init";
  private final String FLYY_SET_NEW_USER = "flyy_set_new_user";
  private final String FLYY_SET_USER = "flyy_set_user";
  private final String FLYY_SET_USER_NAME = "flyy_set_user_name";
  private final String FLYY_SEND_EVENT = "flyy_send_event";
  private final String FLYY_SEND_EVENT_JSON = "flyy_send_event_json";
  private final String FLYY_OPEN_OFFERS_SCREEN = "flyy_open_offers_screen";
  private final String FLYY_OPEN_REWARDS_SCREEN = "flyy_open_rewards_screen";
  private final String FLYY_OPEN_WALLET_SCREEN = "flyy_open_wallet_screen";
  private final String FLYY_OPEN_GIFT_CARDS_SCREEN = "flyy_gift_cards_screen";
  private final String FLYY_OPEN_REFERRAL_SCREEN = "flyy_open_referral_screen";

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "flyy_flutter_plugin");
    channel.setMethodCallHandler(this);
    context = flutterPluginBinding.getApplicationContext();
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, final @NonNull Result result) {
    switch (call.method) {
      case FLYY_INIT:
        Flyy.init(context, String.valueOf(call.argument("partner-token")),
                (Integer) call.argument("environment"));
        showToast(FLYY_INIT);
        break;
      case FLYY_SET_NEW_USER:
        Flyy.setNewUser(String.valueOf(call.argument("ext-uid")), new OnFlyyTaskComplete() {
          @Override
          public void onComplete() {
            result.success("success");
          }
        });
        break;
      case FLYY_SET_USER:
        Flyy.setUser(String.valueOf(call.argument("ext-uid")), new OnFlyyTaskComplete() {
          @Override
          public void onComplete() {
            result.success("success");
          }
        });
        break;
      case FLYY_SET_USER_NAME:
        Flyy.setUsername(String.valueOf(call.argument("user-name")), new OnFlyyTaskComplete() {
          @Override
          public void onComplete() {
            result.success("success");
          }
        });
        break;
      case FLYY_SEND_EVENT:
        Flyy.sendEvent(String.valueOf(call.argument("key")),
                String.valueOf(call.argument("value")),
                new OnFlyyTaskComplete() {
                  @Override
                  public void onComplete() {
                    result.success("success");
                  }
                });
        break;
      case FLYY_SEND_EVENT_JSON:
        Map<String, String> hashMap = call.argument("json_value");

        Flyy.sendEvent(String.valueOf(call.argument("key")),
                new JSONObject(hashMap),
                new OnFlyyTaskComplete() {
                  @Override
                  public void onComplete() {
                    result.success("success");
                  }
                });
        break;
      case FLYY_OPEN_OFFERS_SCREEN:
        if(activity != null) {
          Flyy.navigateToOffersActivity(activity);
        }
        break;
      case FLYY_OPEN_REWARDS_SCREEN:
        if(activity != null) {
          Flyy.navigateToRewardsActivity(activity);
        }
        break;
      case FLYY_OPEN_WALLET_SCREEN:
        if(activity != null) {
          Flyy.navigateToWalletActivity(activity);
        }
        break;
      case FLYY_OPEN_GIFT_CARDS_SCREEN:
        if(activity != null) {
          Flyy.navigateToGiftCardsActivity(activity);
        }
        break;
      case FLYY_OPEN_REFERRAL_SCREEN:
        if(activity != null) {
          Flyy.navigateToReferralHistoryActivity(activity);
        }
        break;
      default:
        result.notImplemented();
        break;
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  @Override
  public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
    activity = binding.getActivity();
//    showToast("onAttachedToActivity");
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {

  }

  @Override
  public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {

  }

  @Override
  public void onDetachedFromActivity() {

  }

  private void showToast(String message) {
    Toast.makeText(activity, message, Toast.LENGTH_SHORT).show();
  }
}

==> 1.0.1.tar.gz: android/src/main/java/com/theflyy/flyy_flutter_plugin/FlyyFlutterPlugin.java <==
package com.theflyy.flyy_flutter_plugin;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.widget.Toast;

import androidx.annotation.NonNull;

import org.json.JSONObject;

import java.util.Map;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import theflyy.com.flyy.Flyy;
import theflyy.com.flyy.helpers.OnFlyyTaskComplete;
import theflyy.com.flyy.views.FlyyGiftCardsActivity;
import theflyy.com.flyy.views.FlyyOffersActivity;
import theflyy.com.flyy.views.FlyyReferralsActivity;
import theflyy.com.flyy.views.FlyyRewardsActivity;
import theflyy.com.flyy.views.FlyyWalletActivity;

/** FlyyFlutterPlugin */
public class FlyyFlutterPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {

  private Context context;
  private Activity activity;
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;

  private final String FLYY_PACKAGE_NAME = "flyy_package_name";
  private final String FLYY_INIT = "flyy_init";
  private final String FLYY_SET_NEW_USER = "flyy_set_new_user";
  private final String FLYY_SET_USER = "flyy_set_user";
  private final String FLYY_SET_USER_NAME = "flyy_set_user_name";
  private final String FLYY_SEND_EVENT = "flyy_send_event";
  private final String FLYY_SEND_EVENT_JSON = "flyy_send_event_json";
  private final String FLYY_OPEN_OFFERS_SCREEN = "flyy_open_offers_screen";
  private final String FLYY_OPEN_REWARDS_SCREEN = "flyy_open_rewards_screen";
  private final String FLYY_OPEN_WALLET_SCREEN = "flyy_open_wallet_screen";
  private final String FLYY_OPEN_GIFT_CARDS_SCREEN = "flyy_gift_cards_screen";
  private final String FLYY_OPEN_REFERRAL_SCREEN = "flyy_open_referral_screen";

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "flyy_flutter_plugin");
    channel.setMethodCallHandler(this);
    context = flutterPluginBinding.getApplicationContext();
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, final @NonNull Result result) {
    switch (call.method) {
      case FLYY_PACKAGE_NAME:
       //TODO ignoring for android, written only for ios for now
        break;
      case FLYY_INIT:
        Flyy.init(context, String.valueOf(call.argument("partner-token")),
                (Integer) call.argument("environment"));
//        showToast(FLYY_INIT);
        break;
      case FLYY_SET_NEW_USER:
        Flyy.setNewUser(String.valueOf(call.argument("ext-uid")), new OnFlyyTaskComplete() {
          @Override
          public void onComplete() {
            result.success("success");
          }
        });
        break;
      case FLYY_SET_USER:
        Flyy.setUser(String.valueOf(call.argument("ext-uid")), new OnFlyyTaskComplete() {
          @Override
          public void onComplete() {
            result.success("success");
          }
        });
        break;
      case FLYY_SET_USER_NAME:
        Flyy.setUsername(String.valueOf(call.argument("user-name")), new OnFlyyTaskComplete() {
          @Override
          public void onComplete() {
            result.success("success");
          }
        });
        break;
      case FLYY_SEND_EVENT:
        Flyy.sendEvent(String.valueOf(call.argument("key")),
                String.valueOf(call.argument("value")),
                new OnFlyyTaskComplete() {
                  @Override
                  public void onComplete() {
                    result.success("success");
                  }
                });
        break;
      case FLYY_SEND_EVENT_JSON:
        Map<String, String> hashMap = call.argument("json_value");

        Flyy.sendEvent(String.valueOf(call.argument("key")),
                new JSONObject(hashMap),
                new OnFlyyTaskComplete() {
                  @Override
                  public void onComplete() {
                    result.success("success");
                  }
                });
        break;
      case FLYY_OPEN_OFFERS_SCREEN:
//        showToast(FLYY_OPEN_OFFERS_SCREEN);
        if(activity != null) {
          Intent intent = new Intent(activity, FlyyOffersActivity.class);
          activity.startActivity(intent);
        }
        /*if(activity != null) {
          Flyy.navigateToOffersActivity(activity);
        }*/
        break;
      case FLYY_OPEN_REWARDS_SCREEN:
        if(activity != null) {
          Intent intent = new Intent(activity, FlyyRewardsActivity.class);
          activity.startActivity(intent);
        }
        break;
      case FLYY_OPEN_WALLET_SCREEN:
        if(activity != null) {
          Intent intent = new Intent(activity, FlyyWalletActivity.class);
          activity.startActivity(intent);
        }
        break;
      case FLYY_OPEN_GIFT_CARDS_SCREEN:
        if(activity != null) {
          Intent intent = new Intent(activity, FlyyGiftCardsActivity.class);
          activity.startActivity(intent);
        }
        break;
      case FLYY_OPEN_REFERRAL_SCREEN:
        if(activity != null) {
          Intent intent = new Intent(activity, FlyyReferralsActivity.class);
          activity.startActivity(intent);
        }
        break;
      default:
        result.notImplemented();
        break;
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  @Override
  public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
    activity = binding.getActivity();
//    showToast("onAttachedToActivity");
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {

  }

  @Override
  public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {

  }

  @Override
  public void onDetachedFromActivity() {

  }

//  private void showToast(String message) {
//    Toast.makeText(activity, message, Toast.LENGTH_SHORT).show();
//  }
}
